@@ -61,8 +61,6 @@ def run_cli(
 
     output = ""
     result = ""
-    processing_result = False
-    processed_result = False
 
     for c in iter(lambda: process.stdout.read(1), ""):
         output += c
@@ -71,9 +69,6 @@ def run_cli(
             sys.stdout.write(c)
             sys.stdout.flush()
 
-        if processed_result == True:
-            processing_result = False
-
     process.wait()
 
     if process.returncode == 0:
